clear all, ex = 'mathieu'; P = 3; 
Tp = 20; N = 7; s = 0.1; NN = 100; fid = 1;
f_missing = linspace(0.05, 0.35, N); 
randn('seed', 0), rand('seed', 0) 
switch lower(ex) 
  case {'mathieu','mathieu2'}, 
    n = 2; p = 1; 
    thb = []; phi0 = eye(n);
    for tau = 1:P, 
      a(:, :, tau) = [0 1; ...
        -.9  -(0.1 + 0.4 * cos(2 * pi / P * tau))]; 
      c(:, :, tau) = [1 0]; 
      thb = [thb; a(end, :, tau)']; 
      phi0 = phi0 * a(:, :, tau);
    end
    th0 = poly(eig(phi0));
  case 'rand', 
    w = rand(1, floor(n / 2)); 
    if mod(n, 2) ~= 0, w = [w 0]; end
    phi = assign_eig(exp(sqrt(-1) * pi * w)); thb = NaN;
    psi = rand(p * P, n); 
    for i = 1:P
      a(:, :, i) = eye(n); 
      c(:, :, i) = psi((i - 1) * p + 1: i * p, :); 
    end
    a(:, :, P) = phi;
end
T = P * Tp; Tid = round(fid * T); 
sys0 = struct('a', a, 'c', c); 
x0 = rand(n, 1); [y0, X0] = pltv_sim(sys0, T, x0); 
yt = randn(size(y0)); 
y = y0 + s * norm(y0, 'fro') * yt / norm(yt, 'fro'); 
methods = 4; clear E,
for ii = 1:N
  for jj = 1:NN
    Im = randperm(T); Tm = round(f_missing(ii) * T); Im = Im(1:Tm);
    ym = y; ym(Im) = NaN;
    [sysh, xhini] = pltv_ident4(ym, P, n);
    yh = pltv_sim(sysh, T, xhini); 
    E(1, ii, jj) = norm(y0(Im) - yh(Im)) / norm(y0(Im)); 
  end
end  
for k = 1:length(methods) 
  rl{k} = ['Alg. ' int2str(methods(k))]; 
end
disp([['% missing'; rl'] num2cell([100 * f_missing; mean(E, 3)])])
cl = cellstr(num2str(100 * f_missing'));
matrix2latex(mean(E, 3), 'error-missing', 'rowLabels', rl, 'columnLabels', cl, 'format', '%-6.4f')
